pub enum WakeupSource {
Ext0 = 0,
Ext1 = 1,
Gpio = 2,
Timer = 3,
Sdio = 4,
Wifi = 5,
Uart0 = 6,
Uart1 = 7,
Touch = 8,
Bt = 10,
UlpRiscv = 11,
UlpRiscvTrap = 13,
}Expand description
A source that can wake the chip from sleep.
Each variant models a single bit in the wakeup registers. This enum is the internal
representation shared by [WakeTriggers][crate::rtc_cntl::sleep::WakeTriggers] (the
sources configured to end a sleep) and WakeupReason (the source(s) that caused the
most recent wakeup, see wakeup_cause).
Note that the available variants depend on the target chip.
Variants
Ext0 = 0
EXT0 wakeup
Ext1 = 1
EXT1 wakeup, via one or more RTC GPIOs (RTC_CNTL).
Gpio = 2
GPIO wakeup.
Timer = 3
Timer wakeup.
Sdio = 4
SDIO wakeup.
Wifi = 5
Wi-Fi (MAC) wakeup.
Uart0 = 6
UART0 wakeup.
Uart1 = 7
UART1 wakeup.
Touch = 8
Touch sensor wakeup.
Bt = 10
Bluetooth wakeup.
UlpRiscv = 11
ULP RISC-V coprocessor wakeup.
UlpRiscvTrap = 13
ULP RISC-V coprocessor trap (crash) wakeup.